==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/IOExtras/UnsafePtrEq.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v159	((void*)startLabel+44)
#define ST_v158	((void*)startLabel+56)
extern Node TM_NHC_46IOExtras[];
void FR_NHC_46IOExtras_46unsafePtrEq(void);

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v159)
,};
Node FN_NHC_46IOExtras_46unsafePtrEq[] = {
  useLabel(TM_NHC_46IOExtras)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46IOExtras_46unsafePtrEq)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 70036
, useLabel(ST_v158)
,	/* CT_v159: (byte 0) */
  HW(0,2)
, 0
,};
Node F0_NHC_46IOExtras_46unsafePtrEq[] = {
  CAPTAG(useLabel(FN_NHC_46IOExtras_46unsafePtrEq),2)
,	/* ST_v158: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(73,79,69,120)
, bytes2word(116,114,97,115)
, bytes2word(46,117,110,115)
, bytes2word(97,102,101,80)
, bytes2word(116,114,69,113)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "unsafePtrEq" NHC.IOExtras.unsafePtrEq 2 :: 1 -> 1 -> Prelude.Bool */
extern HsBool unsafePtrEq(NodePtr,NodePtr);
#ifdef PROFILE
static SInfo pf_unsafePtrEq = {"NHC.IOExtras","NHC.IOExtras.unsafePtrEq","Prelude.Bool"};
#endif
C_HEADER(FR_NHC_46IOExtras_46unsafePtrEq) {
  NodePtr nodeptr;
  HsBool result;
  NodePtr arg1;
  NodePtr arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (NodePtr)nodeptr;
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (NodePtr)nodeptr;

  result = unsafePtrEq(arg1,arg2);

  nodeptr = nhc_mkBool(result);
  INIT_PROFINFO(nodeptr,&pf_unsafePtrEq);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/IOExtras/UnsafePtrEq.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v162	((void*)startLabel+44)
#define ST_v161	((void*)startLabel+56)
extern Node TM_NHC_46IOExtras[];
void FR_NHC_46IOExtras_46unsafePtrEq(void);

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v162)
,};
Node FN_NHC_46IOExtras_46unsafePtrEq[] = {
  useLabel(TM_NHC_46IOExtras)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46IOExtras_46unsafePtrEq)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 70001
, useLabel(ST_v161)
,	/* CT_v162: (byte 0) */
  HW(0,2)
, 0
,};
Node F0_NHC_46IOExtras_46unsafePtrEq[] = {
  CAPTAG(useLabel(FN_NHC_46IOExtras_46unsafePtrEq),2)
,	/* ST_v161: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(73,79,69,120)
, bytes2word(116,114,97,115)
, bytes2word(46,117,110,115)
, bytes2word(97,102,101,80)
, bytes2word(116,114,69,113)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "unsafePtrEq" NHC.IOExtras.unsafePtrEq 2 :: 1 -> 1 -> Prelude.Bool */
extern HsBool unsafePtrEq(NodePtr,NodePtr);
#ifdef PROFILE
static SInfo pf_NHC_46IOExtras_46unsafePtrEq = {"NHC.IOExtras","NHC.IOExtras.unsafePtrEq","Prelude.Bool"};
#endif
C_HEADER(FR_NHC_46IOExtras_46unsafePtrEq) {
  NodePtr nodeptr;
  HsBool result;
  NodePtr arg1;
  NodePtr arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (NodePtr)nodeptr;
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (NodePtr)nodeptr;

  result = unsafePtrEq(arg1,arg2);

  nodeptr = nhc_mkBool(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46IOExtras_46unsafePtrEq);
  C_RETURN(nodeptr);
}
